# chiton

[![PyPI](https://img.shields.io/pypi/v/chiton.svg)](https://pypi.python.org/pypi/chiton)
[![Bioconda](https://img.shields.io/conda/vn/bioconda/chiton.svg?color=43b02a)](https://anaconda.org/bioconda/chiton)

Chiton provides a Python wrapper to commonly used bioinformatics programs.

## Setup

```shell
# PyPI
python -m pip install chiton

# Bioconda
conda install -c bioconda chiton
```

## Supported programs

* [FastANI](https://github.com/ParBLiSS/FastANI) (all versions)


## Contributing

This project uses [Semantic Versioning](http://semver.org/) and [Conventional Commits](https://conventionalcommits.org/)
to automatically generate release notes using [Semantic Release](https://semantic-release.gitbook.io/semantic-release/).

Please ensure that your commits are property formatted.
